@@ -5,12 +5,16 @@ __author__ = 'Danilo Ferri Perogil'
 
 import sys
 from credentials import get_nova_creds
+from credentials import get_keystone_creds
 from novaclient.client import Client
+from openstack.network import networks
+from neutronclient.v2_0 import client
 
 class floatings():
-
-    def __init__(self, iname):
+    def __init__(self, iname=None):
         self.cred = get_nova_creds()
+        self.keystone = get_keystone_creds()
+        self.neutron = client.Client(**self.keystone)
         self.nova = Client(**self.cred)
         self.iname = iname
 
@@ -55,6 +59,8 @@ class floatings():
         else:
             f = self.nova.floating_ips.create(self.nova.floating_ip_pools.list()[0].name)
             self.id_ip = f.id
+        self.ip = self.nova.floating_ips.get(self.id_ip).ip
+
 
     def getip(self, name):
         id = self.nova.servers.find(name=self.iname).id
@@ -67,5 +73,15 @@ class floatings():
         vm = self.nova.servers.find(name=self.iname)
         vm.remove_floating_ip(ip)
 
+    def associate(self, port_id, floating_id=None):
+        floating = floatings()
+        if not floating_id:
+            floating.get()
+            self.neutron.update_floatingip(floating.id_ip,
+                                           {'floatingip': {'port_id': port_id}})
+        else:
+            self.neutron.update_floatingip(floating_id,
+                                           {'floatingip': {'port_id': port_id}})
+
 if __name__ == '__main__':
     floatings()
\ No newline at end of file
